<?php
/**
 * Controller to handling admin chat actions
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Ajax_Admin_actions' ))
{
  class IPCht_Ajax_Admin_actions
  {
    /**
     * Execution save setting
     *
     * @return void
     */
    public function exec()
    {
      global $user_ID;

      $model  = new IPCht_Model_Setting();
      $config = $model->getSettings();

      //
      //Set status
      if ( $config->getSetting( 'online_status', 'true' ) == 'true' )
      {
        $key = md5( time() . $user_ID );
        update_option( '__ipcht_admin_online_status', 1 );
        update_option( '__ipcht_admin_online_time', time() );
        update_option( '__ipcht_admin_current_key', $key );
      } 
      else {
        update_option( '__ipcht_admin_online_status', 0 );
      }

      //
      //Get user online status
      $onlines = $this->_getUserStatus();

      //Try get session
      $modSession = new IPCht_Model_Session();
      $session = false;
      if ( ! empty( $_POST['session'] ))
      {
        $key = apply_filters( 'single_post_title', $_POST['session'] );
        $session = $modSession->getSessionByKey( $key );
      }

      //
      //Get user chats
      $userOnline = 0;
      $chats      = array();
      $lastDate   = '';
      if ( $session )
      {
        $chatsData = IPCht_Chat::createUserChats( $session );
        if ( ! empty( $chatsData['html'] )) {
          $chats = $chatsData['html'];
        }
        $lastDate = $chatsData['last_date'];
        //
        //Get current user status
        $statusOnline = IPCht_Chat::isUserOnline( $session );
        if ( $statusOnline ) {
          $userOnline = 1;
        }
      }

      //
      //Get new users
      $users = $this->_getNewUsers();

      echo json_encode( array(
          'status'      => 1,
          'onlines'     => $onlines,
          'chats'       => $chats,
          'users'       => $users,
          'userOnline'  => $userOnline,
          'last_date'   => $lastDate
      ) );
      die();
    }

    /**
     * Get user status
     *
     * @return void
     */
    protected function _getUserStatus()
    {
      $onlines    = array();
      $modChat    = new IPCht_Model_Chat();
      $modSession = new IPCht_Model_Session();

      $users = $modSession->getUserSessions();
      if ( $users )
      {
        $_users = array();
        foreach( $users as $user )
        {
          $userId = $user->user_id;
          if ( ! array_key_exists($userId, $_users)) {
            $_users[$userId] = $user;
          }
        }

        foreach( $_users as $user )
        {
          if ( IPCht_Chat::isUserOnline( $user ) ) {
            $onlines[] = $user->user_id;
          }
        }
      }

      return $onlines;
    }

    /**
     * Get new users
     *
     * @return void
     */
    protected function _getNewUsers()
    {
      $uresult  = '';
      $modChat  = new IPCht_Model_Chat();
      $modUser  = new IPCht_Model_User();
      $modSett  = new IPCht_Model_Setting();
      $system   = $modSett->getSettings();

      $users = $modUser->getNewUsers();
      if ( $users )
      {
        $colors  = array();
        $_colors = array(
          '#666666',
          '#336eb8',
          '#3da7c6',
          '#33a746',
          '#c14127',
          '#ce6e3a',
          '#ada458',
          '#b55a94',
          '#824b9b',
          '#4e429a',
          '#569f84',
          '#8ba955'
        );

        $thumbType = $system->getSetting( 'user_photo_type', 'name' );
        $userPhoto = false;
        if ( $photoId = $system->getSetting( 'user_photo' ))
        {
          $phdata = wp_get_attachment_image_src( $photoId, 'full' );
          if ( ! empty( $phdata[0] )) {
            $userPhoto = $phdata[0];
          }
        }

        foreach( $users as $user )
        {
          $class = 'ipcht-user ipcht-user-new';
          if ( IPCht_Chat::isUserOnline( $user ) ) {
            $class .= ' ipcht-user-online';
          }

          //
          //Get color
          if ( empty( $colors )) {
            $colors = $_colors;
          }
          $last = count( $colors );
          $rand = rand( 0, $last - 1 );
          $color = $colors[$rand];
          unset( $colors[$rand] );
          sort( $colors );

          //
          //Get label
          $chats = $modChat->getChatsByUser( $user->user_id );
          if ( empty( $chats )) {
            continue;
          }
          $_cht = $chats;
          $last = array_pop( $_cht );
          if ( strlen( $last->chat_message ) > 30 )
          {
            $chmsg  = stripslashes( $last->chat_message );
            $label  = substr( $chmsg, 0, 30 );
            $label .= '...';
          } 
          else {
            $label = stripslashes( $last->chat_message );
          }

          //Get user icon
          $usicon = '';
          if ( $thumbType == 'name' ) 
          {
            $usicon = '<span class="ipcht-user-char">' .
                        substr( $user->user_name, 0, 1 ) . 
                      '</span>';
          }
          elseif ( $thumbType == 'photo' && $userPhoto )
          {
            $ucicon = '<img class="ipcht-user-photo" src="' . $userPhoto . '" alt="">';
          }
          else
          {
            $ucicon = '<span class="ipcht-user-char"></span>';
          }

          $item = '<div class="' . $class . '" data-id="' . $user->user_id . '" data-color="' . $color . '">' .
                    '<div class="ipcht-user-inner">' .
                      '<div class="ipcht-user-icon" style="background-color:' . $color . '">' .
                        $ucicon . 
                      '</div>' .
                    '<div class="ipcht-user-info">' .
                      '<h4 class="ipcht-user-name">' . $user->user_name . '</h4>' .
                      '<p class="ipcht-user-message">' . $label . '</p>' .
                    '</div>' .
                  '</div>' .
                '</div>';

          $uresult .= $item;
        }
      }

      return $uresult;
    }
  }
}
