<?php
/**
 * Controller to handling send chat
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Ajax_Send_chat' ))
{
  class IPCht_Ajax_Send_chat
  {
    //{{ exec

    /**
     * Execution save setting
     *
     * @return void
     */
    public function exec()
    {
      $modSetting = new IPCht_Model_Setting();
      $modSession = new IPCht_Model_Session();
      $modUser    = new IPCht_Model_User();

      //Get system config
      $config = $modSetting->getSettings();

      //Check session
      $session = false;
      if ( isset( $_POST['key'] ) && ! empty( $_POST['key'] ))
      {
        $sessionKey = apply_filters( 'single_post_title', $_POST['key'] );
        $session    = $modSession->getSessionByKey( $sessionKey );
      }
      if ( ! $session )
      {
        echo json_encode( array(
          'status'    => 0,
          'message'   => __( 'Error chat session.', IPCHT_SLUG )
        ) );
        die();
      }

      //Check user
      $user = false;
      if ( ! empty( $session['user_id'] )) {
        $user = $modUser->getUser( $session['user_id'] );
      }
      if ( ! $user )
      {
        echo json_encode( array(
          'status'    => 0,
          'message'   => __( 'Error chat user.', IPCHT_SLUG )
        ) );
        die();
      }

      //Check message
      if ( ! isset( $_POST['message'] ) || empty( $_POST['message'] ))
      {
        echo json_encode( array(
          'status'    => 0,
          'message'   => __( 'Message cannot be empty.', IPCHT_SLUG )
        ) );
        die();
      }
      $message = apply_filters( 'single_post_title', $_POST['message'] );

      if ( IPCht_Chat::isOnline() )
      {
        $this->_saveChat( $session, $user, $message );
      }
      else
      {
        $this->_saveChatOffline( $session, $user, $message );
      }
    }

    //}}
    //{{ _saveChat

    /**
     * Save chat
     *
     * @param  array  $session
     * @param  array  $user
     * @param  string $message
     * @return void
     */
    protected function _saveChat( $session, $user, $message )
    {
      global $user_ID;

      $modUser    = new IPCht_Model_User();
      $modChat    = new IPCht_Model_Chat();
      $modSession = new IPCht_Model_Session();

      if ( isset( $_GET['type'] ) && $_GET['type'] == 'user' ){
        $originates = 2;
      } 
      else {
        $originates = 1;
      }

      //Save chat data
      $chatData = array
      (
        'user_id'             => $user['user_id'],
        'sess_id'             => $session['sess_id'],
        'chat_timestamp'      => date( 'c' ),
        'chat_timestamp_gmt'  => gmdate( 'c' ),
        'chat_key'            => md5( $user['user_id'] . $session['sess_id'] . time() ),
        'chat_message'        => $message,
        'chat_status'         => 1,
        'chat_originates'     => $originates
      );
      $result = $modChat->insertChat( $chatData );

      //Update session
      $toUpdate = array(
        'sess_last_active' => date( 'c' )
      );
      $modSession->updateSession( $session['sess_id'], $toUpdate );

      //
      //Send notif
      IPCht_Chat::sendNotifNewChat( $user, $message );

      //
      //Return result
      //
      $chatId  = 0;
      $status  = 0;
      $message = __( 'Chat failed to save.', IPCHT_SLUG );
      if ( $result )
      {
        $status = 1;
        $chatId = $result;
        $message = __( 'Chat successfully to save.', IPCHT_SLUG );
      }

      echo json_encode( array(
        'status'      => $status,
        'type'        => 'chat',
        'message'     => $message
      ));
      die();

    }

    //}}
    //{{ _saveChatOffline

    /**
     * Save offline message
     *
     * @param  array $session
     * @param  array $user
     * @param  string $message
     * @return void
     */
    protected function _saveChatOffline( $session, $user, $message )
    {
      //Get system config
      $model  = new IPCht_Model_Setting();
      $system = $model->getSettings();

      $failedMsg = stripslashes( $system->getSetting( 'failed_offline_message', __('Failed',IPCHT_SLUG) ) );
      $succesMsg = stripslashes( $system->getSetting( 'success_offline_message', __('Success',IPCHT_SLUG) ) );
      $offMsg    = stripslashes( $system->getSetting( 'offline_message', __('We Offline',IPCHT_SLUG) ) );

      $result = IPCht_Chat::saveOfflineMessageUser( $message, $user );

      //
      //Send notif
      IPCht_Chat::sendNotifOfflineMsgUser( $user, $message );

      if ( $result )
      {
        echo json_encode( array(
          'status'     => 1,
          'type'       => 'offline',
          'message'    => $succesMsg,
          'messageOff' => $offMsg
        ) );
      }
      else
      {
        echo json_encode( array(
          'status'     => 0,
          'type'       => 'offline',
          'message'    => $failedMsg,
          'messageOff' => $offMsg
        ) );
      }
      die();
    }

    //}}


  }
}
