<?php
/**
 * Class helper for create admin setting page
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Admin_Setting' )) 
{
  class IPCht_Admin_Setting extends IPCht_Admin_Manage
  {
		//{{ __construct

		/**
		 * Class construct
		 *
		 * @param array $config
		 * @return void
		 */
		public function __construct( $config = array() )
		{
			$this->_settingName = '__ipcht_system_setting';
			$this->_rootPageID 	= 'ipcht-admin-setting';
			$this->_actionName 	= 'update_setting';

			parent::__construct( $config );
		}

		//}}
		//{{ pageMessage

		/**
		 * Build message in top of page
		 *
		 * @return void
		 */
		public function pageMessage()
		{
			//
			//Dashboard
			if ( $this->isDashboard )
			{
				if ( isset( $_GET['update'] )) 
				{
					$this->htmlMessage( 'Successfully updating plugin settings.' );
				}
			}
		}

		//}}
		//{{ build

		/**
		 * Build admin page
		 *
		 * @return void
		 */
		public function build()
		{
			parent::_setViewData();

			$this->htmlRootID   = 'ipcht-admin-setting';
			$this->singleManage = true;
			
      //Edit page
      $this->manage();
		}

		//}}
		//{{ main

		/**
		 * Main content
		 *
		 * @return void
		 */
		public function main()
		{
			$this->view( 'content-manage' );
		}

		//
		//{{ manageMain

		/**
		 * Build manage main content
		 *
		 * @return void
		 */
		public function manageMain()
		{
			$this->manageGeneral();
			$this->manageUser();
			$this->manageContent();
			$this->manageForm();
			$this->manageNotif();
		}

		//
		//{{ manageGeneral

		/**
		 * Build manage general content
		 *
		 * @return void
		 */
		public function manageGeneral()
		{
			$this->tabId   		= 'ipcht-section-general';
			$this->tabTitle   = __( 'General', IPCHT_SLUG );
			$this->tabInfo    = __( 'Basic chat settings', IPCHT_SLUG );
			$this->tabIcon    = 'cogs';
			$this->tabView    = 'setting/field-general';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageContent

		/**
		 * Build manage content content
		 *
		 * @return void
		 */
		public function manageContent()
		{
			$this->tabId   		= 'ipcht-section-content';
			$this->tabTitle   = __( 'Content', IPCHT_SLUG );
			$this->tabInfo    = __( 'Chat info and message settings', IPCHT_SLUG );
			$this->tabIcon    = 'file-text-o';
			$this->tabView    = 'setting/field-content';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageForm

		/**
		 * Build manage form content
		 *
		 * @return void
		 */
		public function manageForm()
		{
			$this->tabId   		= 'ipcht-section-form';
			$this->tabTitle   = __( 'Form', IPCHT_SLUG );
			$this->tabInfo    = __( 'Chat form settings', IPCHT_SLUG );
			$this->tabIcon    = 'edit';
			$this->tabView    = 'setting/field-form';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageUser

		/**
		 * Build manage user content
		 *
		 * @return void
		 */
		public function manageUser()
		{
			$this->tabId   		= 'ipcht-section-user';
			$this->tabTitle   = __( 'User', IPCHT_SLUG );
			$this->tabInfo    = __( 'Chat user settings', IPCHT_SLUG );
			$this->tabIcon    = 'user';
			$this->tabView    = 'setting/field-user';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageNotif

		/**
		 * Build manage notification content
		 *
		 * @return void
		 */
		public function manageNotif()
		{
			$this->tabId   		= 'ipcht-section-notif';
			$this->tabTitle   = __( 'Notification', IPCHT_SLUG );
			$this->tabInfo    = __( 'Chat notification settings', IPCHT_SLUG );
			$this->tabIcon    = 'bullhorn';
			$this->tabView    = 'setting/field-notif';

			$this->view( 'tab-section' );
		}

		//}}
		//{{ _setManageData

		/**
		 * Set manage data
		 *
		 * @return void
		 */
		protected function _setManageData()
		{
			parent::_setManageData();

			$this->formID 	   = $this->_rootPageID . '-form';
			$this->submitID 	 = $this->_rootPageID . '-save';
      $this->submitIcon  = 'floppy-o';
      $this->submitLabel = __( 'Save Change', IPCHT_SLUG );

			//
			//Set settings
      $model = new IPCht_Model_Setting();
      $this->setting = $model->getSettings();

			$this->requestID = IPCHT_PAGENAME . '-setting';
			$this->pageTitle = __( 'Settings', IPCHT_SLUG );

      //Tab default info
      $this->tabDefaultTitle = __( 'General', IPCHT_SLUG );
      $this->tabDefaultInfo  = __( 'Basic chat settings', IPCHT_SLUG );
      $this->tabDefaultIcon  = 'cogs';
		}

		//}}
		//{{ _setNavManageStructure

		/**
		 * Set navigation structure
		 *
		 * @return void
		 */
		protected function _setNavManageStructure()
		{
			$struct = array
			(
		    'ipcht-section-content' => array(
          'title'     => 'Content',
          'icon'      => 'file-text-o'
		    ),
		    'ipcht-section-form' => array(
          'title'     => 'Form',
          'icon'      => 'edit'
		    ),
		    'ipcht-section-user' => array(
          'title'     => 'User',
          'icon'      => 'user'
		    ),
		    'ipcht-section-notif' => array(
          'title'     => 'Notification',
          'icon'      => 'bullhorn'
		    )
			);
			$this->navManageStructure = $struct;
		}

    //}}
    //{{ getWidgets

    /**
     * Get widgets list
     *
     * @return array
     */
    public function getWidgets()
    {
    	$widgets = array();
      $args = array(
        'orderby'        => 'post_title',
        'order'          => 'ASC',
        'post_type'      => 'ipcht_style',
        'post_status'    => array('publish'),
        'posts_per_page' => -1,
        'paged'          => 1
      );
      $query   = new WP_Query;
      $results = $query->query( $args );
      if ( ! empty( $results )) 
      {
      	foreach( $results as $result ) {
      		$id   = $result->ID;
      		$name = $result->post_title;
      		$widgets[$id] = $name;
      	}
      }
      return $widgets;
    }

    //}}
  }
}