<?php
/**
 * Class helper for create admin page
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Admin_Style' )) 
{
  class IPCht_Admin_Style extends IPCht_Admin_Manage
  {
		//{{ __construct

		/**
		 * Class construct
		 *
		 * @param array $config
		 * @return void
		 */
		public function __construct( $config = array() )
		{
			$this->_settingName = '__ipcht_style_setting';
			$this->_rootPageID 	= 'ipcht-admin-style';
			$this->_actionName 	= 'update_style';

			parent::__construct( $config );
		}

		//}}
		//{{ pageMessage

		/**
		 * Build message in top of page
		 *
		 * @return void
		 */
		public function pageMessage()
		{
			//
			//Dashboard
			if ( $this->isDashboard )
			{
				if ( isset( $_GET['create'] )) 
				{
					$this->htmlMessage( 'Successfully add a style.' );
				}
				elseif ( isset( $_GET['delete'] ))
				{
					$this->htmlMessage( 'Successfully deleting a style.' );
				}
			}
		}

		//}}
		//{{ topButtonAction

		/**
		 * Build button actions in top of page
		 *
		 * @return void
		 */
		public function topButtonActions()
		{
			//
			//Dashboard
			if ( $this->isDashboard )
			{
				$this->htmlButtonAdd( 'Add New Widget', IPCHT_PAGENAME . '-widget', 'create' );
			}
		}

		//
		//{{ manageMain

		/**
		 * Build manage main content
		 *
		 * @return void
		 */
		public function manageMain()
		{
			$this->manageGeneral();
			$this->manageHeader();
			$this->manageFooter();
			$this->manageArea();
			$this->manageInput();
			$this->manageChat();
			$this->manageEffect();
		}

		//
		//{{ manageGeneral

		/**
		 * Build manage general content
		 *
		 * @return void
		 */
		public function manageGeneral()
		{
			$this->tabId   		= 'ipcht-section-general';
			$this->tabTitle   = __( 'General', IPCHT_SLUG );
			$this->tabInfo    = __( 'Basic settings of your widget styles', IPCHT_SLUG );
			$this->tabIcon    = 'cogs';
			$this->tabView    = 'style/field-general';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageHeader

		/**
		 * Build manage header content
		 *
		 * @return void
		 */
		public function manageHeader()
		{
			$this->tabId   		= 'ipcht-section-header';
			$this->tabTitle   = __( 'Header', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the header area of your widget chat', IPCHT_SLUG );
			$this->tabIcon    = 'header';
			$this->tabView    = 'style/field-header';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageFooter

		/**
		 * Build manage footer content
		 *
		 * @return void
		 */
		public function manageFooter()
		{
			$this->tabId   		= 'ipcht-section-footer';
			$this->tabTitle   = __( 'Footer', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the footer area of your widget chat', IPCHT_SLUG );
			$this->tabIcon    = 'level-down';
			$this->tabView    = 'style/field-footer';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageArea

		/**
		 * Build manage chat area
		 *
		 * @return void
		 */
		public function manageArea()
		{
			$this->tabId   		= 'ipcht-section-area';
			$this->tabTitle   = __( 'Chat Area', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the chat area of your widget chat', IPCHT_SLUG );
			$this->tabIcon    = 'square-o';
			$this->tabView    = 'style/field-area';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageInput

		/**
		 * Build manage chat input
		 *
		 * @return void
		 */
		public function manageInput()
		{
			$this->tabId   		= 'ipcht-section-input';
			$this->tabTitle   = __( 'Chat Input', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the chat input', IPCHT_SLUG );
			$this->tabIcon    = 'edit';
			$this->tabView    = 'style/field-input';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageChat

		/**
		 * Build manage chat area
		 *
		 * @return void
		 */
		public function manageChat()
		{
			$this->tabId   		= 'ipcht-section-chat';
			$this->tabTitle   = __( 'Chat Bubble', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set style of the chat buble', IPCHT_SLUG );
			$this->tabIcon    = 'comment';
			$this->tabView    = 'style/field-chat';

			$this->view( 'tab-section' );
		}

		//
		//{{ manageEffect

		/**
		 * Build manage chat area
		 *
		 * @return void
		 */
		public function manageEffect()
		{
			$this->tabId   		= 'ipcht-section-effect';
			$this->tabTitle   = __( 'Effect', IPCHT_SLUG );
			$this->tabInfo    = __( 'Set the effect of your widget chat', IPCHT_SLUG );
			$this->tabIcon    = 'magic';
			$this->tabView    = 'style/field-effect';

			$this->view( 'tab-section' );
		}

		//}}
		//{{ _setDashboardData

		/**
		 * Set manage data
		 *
		 * @return void
		 */
		protected function _setDashboardData()
		{
			parent::_setDashboardData();
			$this->requestID = IPCHT_PAGENAME . '-widget';
		}

		//}}
		//{{ _setManageData

		/**
		 * Set manage data
		 *
		 * @return void
		 */
		protected function _setManageData()
		{
			parent::_setManageData();

			if ( $this->object )
      {
        $pageTitle   = __( 'Edit Widget', IPCHT_SLUG );
      }
      else
      {
        $pageTitle   = __( 'Add Widget', IPCHT_SLUG );

        //Header content
        $this->title = __( 'Add Widget', IPCHT_SLUG );
        $this->info  = 'Add new style for your widget chat.';
      }
			$this->requestID = IPCHT_PAGENAME . '-widget';
			$this->pageTitle = $pageTitle;

      //Tab default info
      $this->tabDefaultTitle = __( 'General', IPCHT_SLUG );
      $this->tabDefaultInfo  = __( 'Basic settings of your widget chat', IPCHT_SLUG );
      $this->tabDefaultIcon  = 'cogs';
		}

		//
		//{{ _getListObject

		/**
		 * Get list object data
		 *
		 * @return void
		 */
		public function _getListObject()
		{
			require_once( IPCHT_LIB . '/list/style.php' );
      $list = new IPCht_List_Style();
      return $list;
		}

		//}}
		//{{ _setNavManageStructure

		/**
		 * Set navigation structure
		 *
		 * @return void
		 */
		protected function _setNavManageStructure()
		{
			$struct = array
			(
		    'ipcht-section-header' => array(
          'title'     => 'Header',
          'icon'      => 'header'
		    ),
		    'ipcht-section-area' => array(
          'title'     => 'Chat Area',
          'icon'      => 'square-o'
		    ),
		    'ipcht-section-input' => array(
          'title'     => 'Chat Input',
          'icon'      => 'edit'
		    ),
		    'ipcht-section-chat' => array(
          'title'     => 'Chat Bubble',
          'icon'      => 'comment'
		    ),
		    'ipcht-section-footer' => array(
          'title'     => 'Footer',
          'icon'      => 'level-down'
		    ),
		    'ipcht-section-effect' => array(
          'title'     => 'Effect',
          'icon'      => 'magic'
		    ),
			);
			$this->navManageStructure = $struct;
		}
  }
}