<?php
if ( ! class_exists( 'IPCht_Db' ))
{
	/**
	 * Class for manage plugin database
	 */
	class IPCht_Db
	{
		/**
		 * Take db version
		 *
		 * @var string
		 */
		public $version = '1.0';

		/**
		 * Class construct
		 *
		 * @return void
		 */
		public function __construct()
		{
			global $ipcht_db_version;
			$ipcht_db_version = $this->version;
		}

		/**
		 * Database query
		 *
		 * @return string
		 */
		public function query_users()
		{
			global $wpdb;

			$table_name = $wpdb->prefix . 'ipcht_users';
			$sql = "CREATE TABLE $table_name (
									user_id       		int(11)             NOT NULL AUTO_INCREMENT,
									wp_user_id      	int(11)             NOT NULL,
									user_created   		datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL, 
									user_created_gmt  datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL, 
									user_name   			varchar(250)        NOT NULL,
									user_email   			varchar(250)        NOT NULL,
									user_phone   			varchar(250)        NOT NULL,
									user_photo   			varchar(250)        NOT NULL,
									user_status   		smallint		        NOT NULL,
							PRIMARY KEY user_id (user_id),
							KEY wp_user_id (wp_user_id)
			);";

			return $sql;
		}

		/**
		 * Database query
		 *
		 * @return string
		 */
		public function query_sessions()
		{
			global $wpdb;

			$table_name = $wpdb->prefix . 'ipcht_sessions';
			$sql = "CREATE TABLE $table_name (
									sess_id       				int(11)             NOT NULL AUTO_INCREMENT,
									user_id      					int(11)             NOT NULL,
									sess_timestamp 				datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									sess_timestamp_gmt		datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									sess_last_active			datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									sess_last_active_gmt	datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									sess_ip   						varchar(100)        NOT NULL,
									sess_key  						varchar(100)        NOT NULL,
									sess_url  						varchar(700)        NOT NULL,
									sess_user_agent				varchar(700)        NOT NULL,
									sess_status  					int(11)             NOT NULL,
									sess_settings					text         				NOT NULL,
							PRIMARY KEY sess_id (sess_id),
							KEY user_id (user_id)
			);";

			return $sql;
		}

		/**
		 * Database query
		 *
		 * @return string
		 */
		public function query_chat()
		{
			global $wpdb;

			$table_name = $wpdb->prefix . 'ipcht_chat';
			$sql = "CREATE TABLE $table_name (
									chat_id       		 int(11)             NOT NULL AUTO_INCREMENT,
									user_id      			 int(11)             NOT NULL,
									sess_id      			 int(11)             NOT NULL,
									chat_timestamp     datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									chat_timestamp_gmt datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									chat_message			 text        				NOT NULL,
									chat_key  				 varchar(100)        NOT NULL,
									chat_status  			 int(3)              NOT NULL,
									chat_originates 	 int(3)              NOT NULL,
							PRIMARY KEY chat_id (chat_id),
							KEY user_id (user_id)
			);";

			return $sql;
		}

		/**
		 * Database query
		 *
		 * @return string
		 */
		public function query_chat_offline()
		{
			global $wpdb;

			$table_name = $wpdb->prefix . 'ipcht_chat_offline';
			$sql = "CREATE TABLE $table_name (
									choff_id       			int(11)             NOT NULL AUTO_INCREMENT,
									user_id      				int(11)             NOT NULL,
									choff_user_name   	varchar(250)        NOT NULL,
									choff_user_email  	varchar(250)        NOT NULL,
									choff_user_phone  	varchar(250)        NOT NULL,
									choff_timestamp  		datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									choff_timestamp_gmt	datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									choff_message				text        				NOT NULL,
									choff_ip   					varchar(100)        NOT NULL,
									choff_key  					varchar(100)        NOT NULL,
									choff_user_agent		varchar(700)        NOT NULL,
									choff_status				smallint        		NOT NULL,
							PRIMARY KEY choff_id (choff_id),
							KEY user_id (user_id)
			);";

			return $sql;
		}

		/**
		 * Database query
		 *
		 * @return string
		 */
		public function query()
		{
			$sql  = '';
			$sql .= $this->query_users();
			$sql .= $this->query_sessions();
			$sql .= $this->query_chat();
			$sql .= $this->query_chat_offline();
			return $sql;
		}

		/**
		 * install
		 *
		 * @return void
		 */
		public function install()
		{
			global $wpdb, $ipcht_db_version;
			$installed_ver = get_option( "ipcht_db_version" );

			if( ! $installed_ver || ( $installed_ver != $ipcht_db_version ) )
			{
				$sql = $this->query();

				require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
				dbDelta( $sql );

				update_option( "ipcht_db_version", $ipcht_db_version );
			}
		}

		/**
		 * update
		 *
		 * @return void
		 */
		public function update()
		{
			global $ipcht_db_version;
			if ( get_site_option( 'ipcht_db_version' ) != $ipcht_db_version ) {
				$this->install();
			}
		}
	}

}
?>
