<?php
/**
 * Class widget model
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Model_Widget' )) 
{
  /**
   * Class for manage main setting
   */
  class IPCht_Model_Widget extends IPCht_Model
  {
    //{{ parameters

    /**
     * Take setting name
     *
     * @var string
     */
    protected $_settingName = '__ipcht_widget_setting';

    //}}
    //{{ saveSettings

    /**
     * Save setting 
     *
     * @return void
     */
    public function saveSettings()
    {
      $data   = $this->_getSettingData();
      $result = update_option( $this->_settingName, $data );
      return $result;
    }

    //}}
    //{{ getSettings

    /**
     * Get setting 
     *
     * @return IPCht_Config
     */
    public function getSettings()
    {
      $settings = array();
      $data     = get_option( $this->_settingName );
      if ( ! empty( $data )) 
      {
        $settings = maybe_unserialize( $data );
      }
      $result = new IPCht_Config( $settings );
      return $result;
    }

    //}}
    //{{ _getSettingStructure

    /**
     * Get setting structure
     *
     * @return array
     */
    protected function _getSettingStructure()
    {
      $structure = array(
        'width'                     => 'int',
        'template'                  => 'term',
        'position'                  => 'term',
        //Tab
        'tab_label'              => 'title',
        'tab_icon'               => 'term',
        'tab_width'              => 'int',
        'tab_height'             => 'int',
        'tab_background_color'   => 'title',
        'tab_color'              => 'title',
        'tab_border_color'       => 'title',
        'tab_border_size'        => 'int',
        'tab_border_radius'      => 'term',
        'tab_font_size'          => 'int',
        'tab_font_family'        => 'term',
        //Header
        'header_height'             => 'int',
        'header_text'               => 'title',
        'header_background_color'   => 'title',
        'header_background_image'   => 'int',
        'header_background_radius'  => 'term',
        'header_background_opacity' => 'int',
        'header_color'              => 'title',
        'header_border_color'       => 'title',
        'header_border_size'        => 'int',
        'header_border_radius'      => 'term',
        'header_font_size'          => 'int',
        'header_font_family'        => 'term',
        //Footer
        'footer_height'             => 'int',
        'footer_text'               => 'title',
        'footer_background_color'   => 'title',
        'footer_color'              => 'title',
        'footer_border_color'       => 'title',
        'footer_border_size'        => 'int',
        'footer_border_radius'      => 'term',
        'footer_font_size'          => 'int',
        'footer_font_family'        => 'term',
        //Chat Area
        'area_height'               => 'int',
        'area_background_color'     => 'title',
        'area_background_image'     => 'int',
        'area_background_radius'    => 'term',
        'area_background_opacity'   => 'int',
        'area_color'                => 'title',
        'area_border_color'         => 'title',
        'area_border_size'          => 'int',
        'area_border_radius'        => 'term',
        'area_font_size'            => 'int',
        'area_font_family'          => 'term',
        'online_message'            => 'title',
        'offline_message'           => 'title',
        'success_offline_message'   => 'title',
        'failed_offline_message'    => 'title',
        //Input Chat
        'form_background_color'     => 'title',
        'form_text_color'           => 'title',
        'form_border_color'         => 'title',
        'form_border_size'          => 'int',
        'form_border_radius'        => 'term',
        'form_font_size'            => 'int',
        'form_font_family'          => 'term',
        'form_input_name'           => 'term',
        'form_input_phone'          => 'term',
        'form_button_label'         => 'title',
        'form_button_icon'          => 'term',
        'form_button_background_color'  => 'title',
        'form_button_color'             => 'title',
        'form_button_border_color'      => 'title',
        'form_button_border_size'       => 'int',
        'form_button_border_radius'     => 'term',
        //Chat Bubble
        'chat_background_color'     => 'title',
        'chat_color'                => 'title',
        'chat_border_color'         => 'title',
        'chat_border_size'          => 'int',
        'chat_border_radius'        => 'term',
        'chat_font_size'            => 'int',
        'chat_font_family'          => 'term',
        'chat_shadow'               => 'term',
        'chat_arrow'                => 'term',
        'chat_photo'                => 'term',
        //Effect
        'shadow'                    => 'term',
        'sending_sound'             => 'int',
        'new_chat_sound'            => 'int',
        'widget_visibility'         => 'term',
        'show_animation'            => 'term',
        'show_animation_speed'      => 'int'
      );
      return $structure;
    }
  }
}
?>
