<?php
/**
 * Controller to handling send offline message
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Ajax_Start_chat' ))
{
  class IPCht_Ajax_Start_chat
  {
    //{{ exec

    /**
     * Execution save setting
     *
     * @return void
     */
    public function exec()
    {
      global $user_ID;

      //Get system config
      $model  = new IPCht_Model_Setting();
      $config = $model->getSettings();

      if ( IPCht_Chat::isOnline() )
      {
        $this->_prepareChat();
      }
      else
      {
        $this->_sendChatOffline();
      }
    }

    //}}
    //{{ _prepareChat

    /**
     * Prepare chat
     *
     * @return void
     */
    protected function _prepareChat()
    {
      //Get system config
      $model  = new IPCht_Model_Setting();
      $config = $model->getSettings();

      $failedMsg = stripslashes( $config->getSetting( 'failed_register_message', __('Failed',IPCHT_SLUG) ));
      $succesMsg = stripslashes( $config->getSetting( 'success_register_message', __('Success',IPCHT_SLUG) ));

      if ( empty( $_POST['email'] ) || empty( $_POST['message'] ) )
      {
        echo json_encode( array(
          'status'    => 0,
          'message'   => $failedMsg
        ) );
        die();
      }

      $name    = '';
      $phone   = '';
      $email   = sanitize_email( $_POST['email'] );
      $chatMsg = apply_filters( 'single_post_title', $_POST['message'] );

      if ( isset( $_POST['name'] )) {
        $name = apply_filters( 'single_post_title', $_POST['name'] );
      }
      if ( isset( $_POST['phone'] )) {
        $phone = apply_filters( 'single_post_title', $_POST['phone'] );
      }

      $result   = false;
      $status   = 0;
      $userId   = $sessId = $chatId = 0;
      $userData = $sessionData = $chatData = array();
      $message  = $failedMsg;
      $sessKey  = '';

      //Try get user based on user email
      $modUser = new IPCht_Model_User();
      if ( $user = $modUser->getUserByEmail( $email ))
      {
        $userData = $user;
        $userId   = $user['user_id'];

        //Update user data
        $toUpdate = array(
          'user_name'     => $name,
          'user_phone'    => $phone
        );
        $modUser->updateUser( $user['user_id'], $toUpdate );
      }
      else
      {
        //Save user data
        $userData = array(
          'wp_user_id'        => 0,
          'user_name'         => $name,
          'user_email'        => $email,
          'user_phone'        => $phone,
          'user_created'      => date( 'c' ),
          'user_created_gmt'  => gmdate( 'c' ),
          'user_status'       => 1
        );
        $userId  = $modUser->insertUser( $userData );
      }

      //Save session
      if ( $userId )
      {
        $sessionData = array(
          'user_id'               => $userId,
          'sess_timestamp'        => date( 'c' ),
          'sess_timestamp_gmt'    => gmdate( 'c' ),
          'sess_last_active'      => date( 'c' ),
          'sess_last_active_gmt'  => gmdate( 'c' ),
          'sess_key'              => md5( $userId . time() . $_SERVER['REMOTE_ADDR'] ),
          'sess_ip'               => $_SERVER['REMOTE_ADDR'],
          'sess_user_agent'       => $_SERVER['HTTP_USER_AGENT'],
          'sess_status'           => 1
        );

        $model  = new IPCht_Model_Session();
        $sessId = $model->insertSession( $sessionData );

        //Save first chat
        if ( $sessId )
        {
          //
          //Set cookie
          setcookie( '__ipcht_chat_session', $sessionData['sess_key'], 0, '/' );
          $sessKey = $sessionData['sess_key'];

          //Save chat data
          $chatData = array(
            'user_id'            => $userId,
            'sess_id'            => $sessId,
            'chat_timestamp'     => date( 'c' ),
            'chat_timestamp_gmt' => gmdate( 'c' ),
            'chat_key'           => md5( $userId . $sessId . time() ),
            'chat_message'       => $chatMsg,
            'chat_status'        => 1, //Terkirim
            'chat_originates'    => 2 //From user
          );

          $model  = new IPCht_Model_Chat();
          $chatId = $model->insertChat( $chatData );

          if ( $chatId ) 
          {
            $result  = true;
            $status  = 1;
            $message = $succesMsg;
          }
        }
      }

      //Return result
      $createData = array_merge( $chatData, $userData );
      $returnData = array(
        'status'      => $status,
        'type'        => 'online',
        'message'     => $message
      );
      if ( $result )
      {
        $returnData['key']       = $sessKey;
        $returnData['user_name'] = $name;
        $returnData['user_char'] = substr( $name, 0, 1 );
        $returnData['chat']      = IPCht_Chat::createChats( $sessionData );
      }
      echo json_encode( $returnData );
      die();
    }

    //}}
    //{{ _sendChatOffline

    /**
     * Send offline message
     *
     * @return void
     */
    protected function _sendChatOffline()
    {
      //Get system config
      $model  = new IPCht_Model_Setting();
      $system = $model->getSettings();

      $failedMsg = stripslashes( $system->getSetting( 'failed_offline_message', __('Failed',IPCHT_SLUG) ));
      $succesMsg = stripslashes( $system->getSetting( 'success_offline_message', __('Success',IPCHT_SLUG) ));
      $offMsg    = stripslashes( $system->getSetting( 'offline_message', __('We Offline',IPCHT_SLUG) ));

      if ( empty( $_POST['email'] ) || empty( $_POST['message'] ) )
      {
        echo json_encode( array(
          'status'    => 0,
          'message'   => $failedMsg
        ) );
        die();
      }

      $result = IPCht_Chat::saveOfflineMessage();

      if ( $result )
      {
        echo json_encode( array(
          'status'     => 1,
          'type'       => 'offline',
          'message'    => $succesMsg,
          'messageOff' => $offMsg
        ) );
      }
      else
      {
        echo json_encode( array(
          'status'     => 0,
          'type'       => 'offline',
          'message'    => $failedMsg,
          'messageOff' => $offMsg
        ) );
      }
      die();
    }

    //}}


  }
}
