<?php
/**
 * Class for create list style
 *
 * @package wp-chat-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_List_Message' )) 
{
  class IPCht_List_Message extends IPCht_List
  {
    //{{ _getData

    /**
     * Get data
     *
     * @return void
     */
    protected function _getData()
    {
      global $wpdb; 

      $page     = $this->_page;
      $per_page = $this->_perPage;

      $args = array
      (
        'perPage' => $per_page,
        'page'    => $page
      );

      $model = new IPCht_Model_ChatOffline();
      $this->_result = $model->getChats( 0, $args );
      $this->_total  = $wpdb->get_var( 'SELECT FOUND_ROWS()' );;
      $this->_total_page = $this->_getTotalPage();
      return $this->_result;
    }

    //}}
    //{{ _getListItem

    /**
     * Get list item
     *
     * @param  object $item
     * @param  int    $index
     * @return string
     */
    protected function _getListItem( $item, $index )
    {
      $alt = '';
      if ( $index % 2 ) {
        $alt = ' ipcht-alt';
      }
      if ( $item->choff_status == 1 ) {
        $alt .= ' ipcht-chat-read';
      } else {
        $alt .= ' ipcht-chat-unread';
      }
      $itemId  = $this->_getListItemId( $item );
      $result  = '<div id="ipcht-item-' . $itemId . '" class="ipcht-list-item' . $alt . '">';
      $result .= '<div class="ipcht-item-inner row">';
      $result .= $this->_getItemMain  ( $item, $index );
      $result .= $this->_getItemAction( $item, $index );
      $result .= '</div>';
      $result .= '</div>';
      return $result;
    }

    //}}
    //{{ _getItemMain

    /**
     * Get item main
     *
     * @param  object $item
     * @param  int    $index
     * @return string
     */
    protected function _getItemMain( $item, $index )
    {
      $title  = $this->_getListItemTitle( $item );
      $date   = mysql2date( 'F d Y, h:i', $this->_getListItemDate( $item ) );

      $link   = $this->_getLinkEdit( $item );
      $label  = $this->_getItemMainLabel( $item, $index );

      $content = strip_tags( $item->choff_message );
      $content = wp_trim_words( $content, 30, ' ...' );

      $result = '<div class="col-sm-12">' .
                      '<div class="ipcht-clear">' .
                          '<div class="ipcht-item-main">' .
                              '<h3 class="ipcht-item-title">' .
                                  '<a href="' . $link . '">' . $title . '</a>' .
                                  $label .
                              '</h3>' .
                              '<p class="ipcht-item-create ipcht-message-date">' .
                                  '<i class="ipcht-fa ipcht-fa-calendar"></i>' .
                                  $date .
                              '</p>' .
                              '<div class="ipcht-message-content">' .
                                  '<i class="ipcht-fa ipcht-fa-quote-right"></i>' .
                                  '<p>' . $content . '</p>' .
                              '</div>' .
                          '</div>' .
                      '</div>' .
                 '</div>';
      return $result;
    }

    //}}
    //{{ _getItemAction

    /**
     * Get item action
     *
     * @param  object $item
     * @param  int    $index
     * @return string
     */
    protected function _getItemAction( $item, $index )
    {
      $itemId  = $this->_getListItemId( $item );
      $result  =
        '<div class="col-sm-3">' .
          '<div class="ipcht-item-action ipcht-clear text-right">' .
            '<div class="ipcht-item-nav ipcht-fademenu">' .
              '<div class="ipcht-fademenu-inner">' .
                '<div class="ipcht-nav-label ipcht-fademenu-button">' .
                  '<a class="ipcht-menu-link" href="#"><i class="ipcht-fa ipcht-fa-bars"></i></a>' .
                '</div>' .
                '<ul class="ipcht-submenu ipcht-fademenu-content">' .
                  '<li>' .
                    '<a href="' . $this->_getLinkEdit( $item ) . '" class="ipcht-btn ipcht-btn-xs ipcht-btn-success">' .
                      '<i class="ipcht-fa ipcht-fa-pencil"></i>' .
                       __( 'View Message', IPCHT_SLUG ) .
                    '</a>' .
                  '</li>' .
                  '<li>' .
                    '<a href="#" class="ipcht-btn ipcht-btn-xs ipcht-btn-danger ipcht-item-msg-delete" data-id="' . $itemId . '">' .
                      '<i class="ipcht-fa ipcht-fa-trash"></i>' .
                      __( 'Delete Message', IPCHT_SLUG ) .
                    '</a>' .
                  '</li>' .
                '</ul>' .
              '</div>' .
            '</div>' .
          '</div>' .
        '</div>';
      return $result;
    }

    //}}
    //{{ _getItemMainLabel

    /**
     * Get item main label
     *
     * @param  object $item
     * @param  int    $index
     * @return string
     */
    protected function _getItemMainLabel( $item, $index )
    {
      return '';
    }

    //}}
    //{{ _getListItemId

    /**
     * Get list item ID
     *
     * @param  object $item
     * @return string
     */
    protected function _getListItemId( $item )
    {
      return $item->choff_id;
    }

    //}}
    //{{ _getListItemTitle

    /**
     * Get list item title
     *
     * @param  object $item
     * @return string
     */
    protected function _getListItemTitle( $item )
    {
      return $item->choff_user_name;
    }

    //}}
    //{{ _getListItemDate

    /**
     * Get list item date
     *
     * @param  object $item
     * @return string
     */
    protected function _getListItemDate( $item )
    {
      return $item->choff_timestamp;
    }

    //}}
    //{{ _getLinkEdit

    /**
     * Get link edit
     *
     * @param  object $item
     * @return string
     */
    protected function _getLinkEdit( $item )
    {
      $link = admin_url() . 'admin.php?page=' . IPCHT_PAGENAME . '-offline&action=view&id=' . $item->choff_id;
      return $link;
    }

    //}}
    //{{ _getPaginationLink

    /**
     * Get pagination link
     *
     * @param  int $page
     * @return string
     */
    protected function _getPaginationLink( $page )
    {
      $link = admin_url() . 'admin.php?page=' . IPCHT_PAGENAME . '-offline&paged=' . $page;
      return $link;
    }

    //}}
  }

}