<?php
/**
 * Class user model
 *
 * @package wp-user-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPCht_Model_User' )) 
{
	/**
	 * Class for manage user data
	 */
	class IPCht_Model_User extends IPCht_Model
	{
		/**
		 * Get Users
		 *
		 * @return int    $count
		 * @return array
		 */
		public function getUsers( $count = 0 )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_users';
			$query  = "
					SELECT * FROM $table
					ORDER BY user_name ASC
			";
			if ( ! empty( $count )) {
				$query .= " LIMIT $count OFFSET 0";
			}
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get new users
		 *
		 * @return string $date
		 * @return int    $count
		 * @return array
		 */
		public function getNewUsers( $date = null, $count = 0 )
		{
			global $wpdb;

			if ( empty( $date )) 
			{
				$now  = time();
				$now -= 5;
				$date = gmdate( 'Y-m-d h:i:s', $now );
			}
			$table1 = $wpdb->prefix . 'ipcht_chat';
			$table2 = $wpdb->prefix . 'ipcht_users';
			$table3 = $wpdb->prefix . 'ipcht_sessions';
			$query  = "
					SELECT * FROM $table2
						JOIN $table3 
							ON $table2.user_id = $table3.user_id
					WHERE
						DATE_FORMAT( $table2.user_created_gmt, '%Y-%m-%d %h:%i:%s' ) >= '$date'";
			
			$query .= " ORDER BY $table2.user_created_gmt DESC";
			
			if ( ! empty( $count )) {
				$query .= " LIMIT $count OFFSET 0";
			}

			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get User
		 *
		 * @return int   $userId
		 * @return array
		 */
		public function getUser( $userId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_users';
			$query  = "
					SELECT * FROM $table
					WHERE
						user_id = $userId
			";
			$results = $wpdb->get_row( $query, ARRAY_A );
			return $results;
		}

		/**
		 * Get User by email
		 *
		 * @return string $email
		 * @return array
		 */
		public function getUserByEmail( $email )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_users';
			$query  = "
					SELECT * FROM $table
					WHERE
						user_email = '$email'
			";
			$results = $wpdb->get_row( $query, ARRAY_A );
			return $results;
		}

		/**
		 * Get Total userss
		 *
		 * @return array
		 */
		public function getTotalUsers()
		{
			global $wpdb;

			$table  = $wpdb->prefix . 'ipcht_users';
			$query  = "
					SELECT
						COUNT( * )
					FROM $table
			";
			$result = $wpdb->get_var( $query );
			$count  = 0;
			if ( $result ) {
				$count = $result;
			}
			return $count;
		}

		/**
		 * Insert User
		 *
		 * @param  array $data
		 * @param  array $format
		 * @return void
		 */
		public function insertUser( $data, $format = array() )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipcht_users';
				$data   = (array)$data;

				$result = $wpdb->insert( $table, $data, $format );
				if ( $result ) {
						return $wpdb->insert_id;
				}
				return false;
		}

		/**
		 * Update User
		 *
		 * @param  int   $id
		 * @param  array $data
		 * @return void
		 */
		public function updateUser( $id, $data )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipcht_users';
				$data   = (array)$data;
				$where  = array(
						'user_id' => absint( $id )
				);
				$result = $wpdb->update( $table, $data, $where );
				return $result;
		}

		/**
		 * Delete User
		 *
		 * @param  int   $id
		 * @return void
		 */
		public function deleteUser( $id )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipcht_users';
			$where  = array(
					'user_id' => absint( $id )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}

	}
}